"""SACAD cover sources."""

from sacad.sources.deezer import DeezerCoverSource, DeezerCoverSourceResult  # noqa: F401
from sacad.sources.discogs import DiscogsCoverSource, DiscogsCoverSourceResult  # noqa: F401
from sacad.sources.itunes import ItunesCoverSource, ItunesCoverSourceResult  # noqa: F401
from sacad.sources.lastfm import LastFmCoverSource, LastFmCoverSourceResult  # noqa: F401
